package com.vendor.burn.model.cmdline.adapter;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.burn.Messages;
import com.vendor.burn.log.Log;
import com.vendor.burn.model.PartitionInfo;
import com.vendor.burn.model.PartitionItem;
import com.vendor.burn.model.cmdline.SplitImgParam;
import com.vendor.burn.model.cmdline.adapter.CommonAdapter;
import com.vendor.burn.utilitily.StringUtils;
import java.io.File;
import java.util.List;
import org.dom4j.DocumentException;
import org.eclipse.osgi.util.NLS;

public class SplitImg extends CommonAdapter {
  long ddrSize;
  
  private String xmlPath;
  
  private String outputPath;
  
  private List<PartitionItem> partitionList;
  
  public boolean parseAllParameter(String[] args, int paramSize) {
    if (!parseXmlPath(args, paramSize)) {
      printSplitImgEg();
      return false;
    } 
    if (!parseDdrSize(args, paramSize)) {
      printSplitImgEg();
      return false;
    } 
    if (!parseOutputFile(args, paramSize)) {
      printSplitImgEg();
      return false;
    } 
    return true;
  }
  
  private boolean parseDdrSize(String[] args, int paramSize) {
    if (args == null) {
      Log.errorln(NLS.bind(Messages.CMD_PARAMETER_NotFound, SplitImgParam.ddrSize.name()));
      return false;
    } 
    if (paramSize >= SplitImgParam.ddrSize.ordinal()) {
      String ddrSize = args[SplitImgParam.ddrSize.ordinal()];
      if (!StringUtils.isLong(ddrSize)) {
        Log.errorln(NLS.bind(Messages.CMD_PARAMETER_IsNull, SplitImgParam.ddrSize.name()));
        return false;
      } 
      setDdrSize(Long.parseLong(ddrSize));
    } else {
      Log.errorln(NLS.bind(Messages.CMD_PARAMETER_NotFound, SplitImgParam.ddrSize.name()));
      return false;
    } 
    return true;
  }
  
  private boolean parseOutputFile(String[] args, int paramSize) {
    if (args == null) {
      Log.errorln(NLS.bind(Messages.CMD_PARAMETER_NotFound, SplitImgParam.outputFile.name()));
      return false;
    } 
    if (paramSize >= SplitImgParam.outputFile.ordinal()) {
      String outputFilePath = args[SplitImgParam.outputFile.ordinal()];
      boolean result = (outputFilePath == null || outputFilePath.isEmpty());
      if (result) {
        Log.errorln(NLS.bind(Messages.CMD_PARAMETER_IsNull, SplitImgParam.outputFile.name()));
        return false;
      } 
      File file = new File(outputFilePath);
      if (!file.isDirectory()) {
        Log.errorln(NLS.bind(Messages.SplitImg_msg_the_path_can__be_a_directory, file.getName()));
        return false;
      } 
      setOutputPath(outputFilePath);
    } else {
      String xmlPath = args[SplitImgParam.xmlPath.ordinal()];
      if (xmlPath == null || xmlPath.isEmpty())
        return false; 
      File file = new File(xmlPath);
      String outFilePath = file.getParent();
      setOutputPath(outFilePath);
    } 
    return true;
  }
  
  private boolean parseXmlPath(String[] args, int paramSize) {
    if (args == null) {
      Log.errorln(NLS.bind(Messages.CMD_PARAMETER_NotFound, SplitImgParam.xmlPath.name()));
      return false;
    } 
    if (paramSize >= SplitImgParam.xmlPath.ordinal()) {
      String xmlPath = args[SplitImgParam.xmlPath.ordinal()];
      if (xmlPath == null)
        return false; 
      File file = new File(xmlPath);
      if (!file.exists() || !file.isFile()) {
        Log.errorln(NLS.bind(Messages.ERROR_CURRENT_XML_PATH_NOT_FOUND, xmlPath));
        return false;
      } 
      try {
        PartitionInfo partitionInfo = PartitionItem.load(file, true);
        List<PartitionItem> partitionList = partitionInfo.getChildren();
        if (partitionList != null && partitionList.size() > 0) {
          setXmlPath(xmlPath);
          setPartitionList(partitionList);
          return true;
        } 
        Log.errorln(NLS.bind(Messages.MESSAGE_FAILED_To_LOAD_FILE, file.getName()));
        return false;
      } catch (DocumentException e) {
        Log.errorln(NLS.bind(Messages.MESSAGE_FAILED_To_LOAD_FILE, file.getName()));
        return false;
      } 
    } 
    Log.errorln(NLS.bind(Messages.CMD_PARAMETER_NotFound, SplitImgParam.xmlPath.name()));
    return false;
  }
  
  private static void printSplitImgEg() {
    Log.println("burntoolcli.jar --splitimg  <xmlPath>                  <ddrSize>             <outputFile>          ");
    Log.println("burntoolcli.jar --emmcimg  image/emmc_partitions.xml    0x10000               image/split  ");
  }
  
  public String getXmlPath() {
    return this.xmlPath;
  }
  
  public void setXmlPath(String xmlPath) {
    this.xmlPath = xmlPath;
  }
  
  public List<PartitionItem> getPartitionList() {
    return this.partitionList;
  }
  
  public void setPartitionList(List<PartitionItem> partitionList) {
    this.partitionList = partitionList;
  }
  
  public String getOutputPath() {
    return this.outputPath;
  }
  
  public void setOutputPath(String outputPath) {
    this.outputPath = outputPath;
  }
  
  public long getDdrSize() {
    return this.ddrSize;
  }
  
  public void setDdrSize(long ddrSize) {
    this.ddrSize = ddrSize;
  }
}
